Ansys Common Tools |version|
############################

Ansys Common Tools provides a collection of tools for the PyAnsys ecosystem.



.. grid:: 1 2 2 2


    .. grid-item-card:: Getting started :material-regular:`directions_run`
        :padding: 2 2 2 2
        :link: getting_started/index
        :link-type: doc

        Learn how to install Ansys Common Tools in user mode.

    .. grid-item-card:: User guide :material-regular:`menu_book`
        :padding: 2 2 2 2
        :link: user_guide/index
        :link-type: doc

        Understand key concepts for implementing the tools
        in your workflows.


    .. grid-item-card:: API reference :material-regular:`bookmark`
        :padding: 2 2 2 2
        :link: api/index
        :link-type: doc

        Understand how to use Python to interact programmatically with the tools.

    .. grid-item-card:: Examples :material-regular:`play_arrow`
        :padding: 2 2 2 2
        :link: examples/index
        :link-type: doc

        Explore examples that show how to use the different tools in practice.

    .. grid-item-card:: Contribute :material-regular:`group`
        :padding: 2 2 2 2
        :link: contributing
        :link-type: doc

        Learn how to contribute to the Ansys Common Tools codebase or documentation.




.. toctree::
    :hidden:
    :maxdepth: 3

    getting_started/index
    user_guide/index
    api/index
    examples/index
    contributing
    changelog
